@@ -11,6 +11,7 @@ import (
 	"github.com/urfave/cli/v2"
 )
 
+//nolint:gochecknoglobals // we need global list of commands
 var commands = []*cli.Command{
 	new(action.Build).Cmd(),
 	new(action.Diff).Cmd(),
@@ -21,20 +22,44 @@ var commands = []*cli.Command{
 	new(action.Down).Cmd(),
 	new(action.Validate).Cmd(),
 	new(action.Yml).Cmd(),
+	new(action.GenSchema).Cmd(),
 	version(),
 	completion(),
 }
 
 func main() {
+	c := CreateApp()
+
+	defer recoverPanic()
+
+	if err := c.Run(os.Args); err != nil {
+		log.Fatal(err) //nolint:gocritic // we try to recover panics, not regural command errors
+	}
+}
+
+func recoverPanic() {
+	if r := recover(); r != nil {
+		switch r.(type) {
+		case CommandNotFoundError:
+			log.Error(r)
+			log.Exit(127)
+		default:
+			log.Panic(r)
+		}
+	}
+}
+
+// CreateApp creates *cli.App with all commands.
+func CreateApp() *cli.App {
 	c := cli.NewApp()
+
 	c.EnableBashCompletion = true
 	c.Usage = "is like docker-compose for helm"
 	c.Version = helmwave.Version
-	c.Description =
-		"This tool helps you compose your helm releases!\n" +
-			"0. $ helmwave yml\n" +
-			"1. $ helmwave build\n" +
-			"2. $ helmwave up\n"
+	c.Description = "This tool helps you compose your helm releases!\n" +
+		"0. $ helmwave yml\n" +
+		"1. $ helmwave build\n" +
+		"2. $ helmwave up\n"
 
 	logSet := logSetup.Settings{}
 	c.Before = logSet.Run
@@ -43,15 +68,23 @@ func main() {
 	c.Commands = commands
 	c.CommandNotFound = command404
 
-	err := c.Run(os.Args)
-	if err != nil {
-		log.Fatal(err)
-	}
+	return c
+}
+
+// CommandNotFoundError is return when CLI command is not found.
+type CommandNotFoundError struct {
+	Command string
+}
+
+func (e CommandNotFoundError) Error() string {
+	return fmt.Sprintf("👻 Command %q not found", e.Command)
 }
 
 func command404(c *cli.Context, s string) {
-	log.Errorf("👻 Command %q not found", s)
-	os.Exit(127)
+	err := CommandNotFoundError{
+		Command: s,
+	}
+	panic(err)
 }
 
 func version() *cli.Command {
@@ -60,7 +93,8 @@ func version() *cli.Command {
 		Aliases: []string{"ver"},
 		Usage:   "Show shorts version",
 		Action: func(c *cli.Context) error {
-			fmt.Println(helmwave.Version) // nolint:forbidigo
+			fmt.Println(helmwave.Version) //nolint:forbidigo // we need to use fmt.Println here
+
 			return nil
 		},
 	}
