@@ -1,13 +1,19 @@
 package plan
 
 import (
+	"context"
+
 	log "github.com/sirupsen/logrus"
 )
 
-// Build plan with yml and tags/matchALL options
-func (p *Plan) Build(yml string, tags []string, matchAll bool) error {
+// Build plan with yml and tags/matchALL options.
+//
+//nolint:funlen
+func (p *Plan) Build(ctx context.Context, yml string, tags []string, matchAll bool, templater string) error {
+	p.templater = templater
+
 	// Create Body
-	body, err := NewBody(yml)
+	body, err := NewBody(ctx, yml)
 	if err != nil {
 		return err
 	}
@@ -15,7 +21,10 @@ func (p *Plan) Build(yml string, tags []string, matchAll bool) error {
 
 	// Build Releases
 	log.Info("Building releases...")
-	p.body.Releases = buildReleases(tags, p.body.Releases, matchAll)
+	p.body.Releases, err = buildReleases(tags, p.body.Releases, matchAll)
+	if err != nil {
+		return err
+	}
 	if len(p.body.Releases) == 0 {
 		return nil
 	}
@@ -27,30 +36,47 @@ func (p *Plan) Build(yml string, tags []string, matchAll bool) error {
 
 	// Build Values
 	log.Info("Building values...")
-	err = p.buildValues(p.tmpDir)
+	err = p.buildValues()
 	if err != nil {
 		return err
 	}
 
 	// Build Repositories
 	log.Info("Building repositories...")
-	_, err = buildRepositories(
-		buildRepoMapTop(p.body.Releases),
-		p.body.Repositories,
-	)
+	_, err = p.buildRepositories()
 	if err != nil {
 		return err
 	}
 
-	// Sync All
-	err = syncRepositories(p.body.Repositories)
+	// Sync Repositories
+	err = SyncRepositories(ctx, p.body.Repositories)
+	if err != nil {
+		return err
+	}
+
+	// Build Registries
+	log.Info("Building registries...")
+	_, err = p.buildRegistries()
+	if err != nil {
+		return err
+	}
+
+	// Sync Registries
+	err = p.syncRegistries(ctx)
+	if err != nil {
+		return err
+	}
+
+	// to build charts we need repositories and registries first
+	log.Info("Building charts...")
+	err = p.buildCharts()
 	if err != nil {
 		return err
 	}
 
 	// Build Manifest
 	log.Info("Building manifests...")
-	err = p.buildManifest()
+	err = p.buildManifest(ctx)
 	if err != nil {
 		return err
 	}
