@@ -1,17 +1,21 @@
 package plan
 
 import (
+	"context"
 	"errors"
+	"fmt"
 	"os"
 	"path/filepath"
+	"strings"
 
 	"github.com/helmwave/helmwave/pkg/release/uniqname"
 	"github.com/helmwave/helmwave/pkg/version"
 	log "github.com/sirupsen/logrus"
 )
 
-func (p *Plan) Import() error {
-	body, err := NewBody(p.fullPath)
+// Import parses directory with plan files and imports them into structure.
+func (p *Plan) Import(ctx context.Context) error {
+	body, err := NewBody(ctx, p.fullPath)
 	if err != nil {
 		return err
 	}
@@ -26,15 +30,23 @@ func (p *Plan) Import() error {
 	}
 
 	p.body = body
+
+	// Check all files exist.
+	err = p.ValidateValuesImport()
+	if err != nil {
+		return err
+	}
+
 	version.Check(p.body.Version, version.Version)
 
 	return nil
 }
 
 func (p *Plan) importManifest() error {
-	ls, err := os.ReadDir(filepath.Join(p.dir, Manifest))
+	d := filepath.Join(p.dir, Manifest)
+	ls, err := os.ReadDir(d)
 	if err != nil {
-		return err
+		return fmt.Errorf("failed to read manifest dir %s: %w", d, err)
 	}
 
 	if len(ls) == 0 {
@@ -42,22 +54,20 @@ func (p *Plan) importManifest() error {
 	}
 
 	for _, l := range ls {
-		if !l.IsDir() {
-			c, err := os.ReadFile(filepath.Join(p.dir, Manifest, l.Name()))
-			if err != nil {
-				return err
-			}
-
-			n := l.Name()[:len(l.Name())-4]
-
-			p.manifests[uniqname.UniqName(n)] = string(c)
+		if l.IsDir() {
+			continue
 		}
+
+		f := filepath.Join(p.dir, Manifest, l.Name())
+		c, err := os.ReadFile(f)
+		if err != nil {
+			return fmt.Errorf("failed to read manifest %s: %w", f, err)
+		}
+
+		n := strings.TrimSuffix(l.Name(), filepath.Ext(l.Name())) // drop extension of file
+
+		p.manifests[uniqname.UniqName(n)] = string(c)
 	}
 
 	return nil
 }
-
-func (p *Plan) Clean() {
-	_ = os.RemoveAll(p.dir)
-	_ = os.RemoveAll(p.fullPath)
-}
